package hu.bme.mit.books.manager;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import hu.bme.mit.books.model.Book;


import org.eclipse.core.databinding.observable.list.WritableList;

public class BookManager implements IBookManager{

	List<Book> books;
	WritableList bookListObservable;

	/**
	 * Instantiates a new book manager with three sample books.
	 */
	public BookManager() {
		books = new ArrayList<Book>();
		addBook("Terry Pratchett", "The Light Fantastic", 232, true);
		addBook("Neil Gaiman", "American Gods", 560, true);
		addBook("Test author", "Test Book", 123, false);
	}

	/**
	 * Gets the all books.
	 * 
	 * @return the all books
	 */
	@Override
	public WritableList getAllBooks() {
		if (bookListObservable == null)
			bookListObservable = new WritableList(books, Book.class);
		return bookListObservable;
	}

	/**
	 * Adds a book with a given author, title, page number to the manager, and
	 * sets whether it is read or not.
	 * 
	 * @param author
	 *            the author
	 * @param title
	 *            the title
	 * @param pages
	 *            the pages
	 * @param read
	 *            the read
	 */
	@Override
	public void addBook(String author, String title, int pages, boolean read) {
		Book book = new Book();
		book.setAuthor(author);
		book.setTitle(title);
		book.setPagenum(pages);
		book.setRead(read);
		addBook(book);
	}
	
	@Override
	public void addBook(Book book) {
		if (bookListObservable != null) {
			bookListObservable.add(book);
		} else {
			books.add(book);
		}
	}
	
	@Override
	public void removeBook(Book book) {
		if (bookListObservable != null) {
			bookListObservable.remove(book);
		} else {
			books.remove(book);
		}
	}
}
