package hu.bme.mit.books.model;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

/**
 * A class for storing books. The class stores for each book its title, author,
 * the number of its pages and whether it has been read or not.
 * @author meres
 */
public class Book {

	String title, author;
	int pagenum;
	boolean read;
	private PropertyChangeSupport changeSupport = new PropertyChangeSupport(
			this);

	public void addPropertyChangeListener(String propertyName,
			PropertyChangeListener listener) {
		changeSupport.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(String propertyName,
			PropertyChangeListener listener) {
		changeSupport.removePropertyChangeListener(listener);
	}

	public String getTitle() {
		return title;
	}

	/**
	 * Sets the title.
	 * @param title
	 *            the new title
	 */
	public void setTitle(String title) {
		String oldTitle = this.title;
		this.title = title;
		changeSupport.firePropertyChange("title", oldTitle, title);
		changeSupport.firePropertyChange("description", oldTitle, title);
	}

	/**
	 * Gets the author.
	 * @return the author
	 */
	public String getAuthor() {
		return author;
	}

	/**
	 * Sets the author.
	 * @param author
	 *            the new author
	 */
	public void setAuthor(String author) {
		String oldAuthor = this.author;
		this.author = author;
		changeSupport.firePropertyChange("author", oldAuthor, author);
		changeSupport.firePropertyChange("description", oldAuthor, author);
	}

	/**
	 * Gets the page num.
	 * @return the page num
	 */
	public Integer getPagenum() {
		return pagenum;
	}

	/**
	 * Sets the page num.
	 * @param pagenum
	 *            the new page num
	 */
	public void setPagenum(Integer pagenum) {
		Integer oldNum = this.pagenum;
		this.pagenum = pagenum;
		changeSupport.firePropertyChange("pagenum", oldNum, pagenum);
	}

	/**
	 * Checks if is read.
	 * @return true, if is read
	 */
	public boolean isRead() {
		return read;
	}

	/**
	 * Sets the read.
	 * @param read
	 *            the new read
	 */
	public void setRead(boolean read) {
		boolean oldRead = this.read;
		this.read = read;
		changeSupport.firePropertyChange("read", oldRead, read);
	}
	
	public String getDescription() {
		return String.format("%s : %s", author, title);
	}

	@Override
	public String toString() {
		return author + ": " + title + " (" + pagenum + " pages), read=" + read;
	}
}
